=======
History
=======

0.3.0 (2025-07-16)
------------------
* Add support for slixmpp

0.2.1 (2025-05-19)
------------------

* Refactor code to imitate the response format of aioxmpp
* Improve documentation

0.2.0 (2024-12-17)
------------------

* Migration to the `Slixmpp <https://pypi.org/project/slixmpp/>`_ library for PubSub operations
* Refactor and fix of the previous tests

0.1.3 (2021-06-29)
------------------

* Minor bug fixed.

0.1.2 (2021-06-25)
------------------

* First release on PyPI.
